@@ -8,19 +8,15 @@ This program can be distributed under the terms of the GNU GPLv3.
 
 from __future__ import division, print_function, absolute_import
 from . import CURRENT_FS_REV, REV_VER_MAP
-from .backends.common import BetterBucket, get_bucket
-from .common import (QuietError, BUFSIZE, setup_logging, get_bucket_cachedir,
-    get_seq_no, stream_write_bz2, CTRL_INODE)
+from .backends.common import BetterBucket, get_bucket, NoSuchBucket
+from .common import (QuietError, BUFSIZE, setup_logging, get_bucket_cachedir, get_seq_no, 
+    stream_write_bz2, stream_read_bz2, CTRL_INODE)
 from .database import Connection, NoSuchRowError
-from .fsck import Fsck
-from .metadata import (restore_metadata, cycle_metadata, dump_metadata,
-    create_tables)
+from .metadata import restore_metadata, cycle_metadata, dump_metadata, create_tables
 from .parse_args import ArgumentParser
 from datetime import datetime as Datetime
 from getpass import getpass
 from llfuse import ROOT_INODE
-from s3ql.backends.common import NoSuchBucket
-from s3ql.common import stream_read_bz2
 import cPickle as pickle
 import logging
 import lzma
@@ -65,6 +61,7 @@ def parse_args(args):
     parser.add_quiet()
     parser.add_log()
     parser.add_authfile()
+    parser.add_ssl()
     parser.add_cachedir()
     parser.add_version()
 
@@ -213,10 +210,8 @@ def clear(bucket, cachepath):
 
     bucket.clear()
 
-    print('File system deleted.')
-
-    if not bucket.is_get_consistent():
-        log.info('Note: it may take a while for the removals to propagate through the backend.')
+    log.info('File system deleted.')
+    log.info('Note: it may take a while for the removals to propagate through the backend.')
 
 def get_old_rev_msg(rev, prog):
     return textwrap.dedent('''\
@@ -263,20 +258,13 @@ def upgrade(bucket, cachepath):
 
     # Check for unclean shutdown
     if param['seq_no'] < seq_no:
-        if bucket.is_get_consistent():
-            print(textwrap.fill(textwrap.dedent('''\
-                It appears that the file system is still mounted somewhere else. If this is not
-                the case, the file system may have not been unmounted cleanly and you should try
-                to run fsck on the computer where the file system has been mounted most recently.
-                ''')))
-        else:
-            print(textwrap.fill(textwrap.dedent('''\
-                It appears that the file system is still mounted somewhere else. If this is not the
-                case, the file system may have not been unmounted cleanly or the data from the 
-                most-recent mount may have not yet propagated through the backend. In the later case,
-                waiting for a while should fix the problem, in the former case you should try to run
-                fsck on the computer where the file system has been mounted most recently.
-                ''')))
+        print(textwrap.fill(textwrap.dedent('''\
+            Backend reports that fs is still mounted. If this is not the case, the file system may
+            have not been unmounted cleanly or the data from the most-recent mount may have not yet
+            propagated through the backend. In the later case, waiting for a while should fix the
+            problem, in the former case you should try to run fsck on the computer where the file
+            system has been mounted most recently.
+            ''')))
 
         print(get_old_rev_msg(param['revision'], 'fsck.s3ql'))
         raise QuietError()
