@@ -321,25 +321,6 @@ class AbstractBucket(object):
 
         pass
 
-    @abstractmethod
-    def is_get_consistent(self):
-        '''If True, objects retrievals are guaranteed to be up-to-date
-        
-        If this method returns True, then creating, deleting, or overwriting an
-        object is guaranteed to be immediately reflected in subsequent object
-        retrieval attempts.
-        '''
-        pass
-
-    @abstractmethod
-    def is_list_create_consistent(self):
-        '''If True, new objects are guaranteed to show up in object listings
-        
-        If this method returns True, creation of objects will immediately be
-        reflected when retrieving the list of available objects.
-        '''
-        pass
-
     @abstractmethod
     def clear(self):
         """Delete all objects in bucket"""
@@ -572,23 +553,6 @@ class BetterBucket(AbstractBucket):
 
         return fh
 
-    def is_get_consistent(self):
-        '''If True, objects retrievals are guaranteed to be up-to-date
-        
-        If this method returns True, then creating, deleting, or overwriting an
-        object is guaranteed to be immediately reflected in subsequent object
-        retrieval attempts.
-        '''
-        return self.bucket.is_get_consistent()
-
-    def is_list_create_consistent(self):
-        '''If True, new objects are guaranteed to show up in object listings
-        
-        If this method returns True, creation of objects will immediately be
-        reflected when retrieving the list of available objects.
-        '''
-        return self.bucket.is_get_consistent()
-
     def clear(self):
         """Delete all objects in bucket"""
         return self.bucket.clear()
@@ -1136,7 +1100,7 @@ def get_bucket(options, plain=False):
 
     return get_bucket_factory(options, plain)()
 
-def get_bucket_factory(options, plain=False):
+def get_bucket_factory(options, plain=False, ssl=False):
     '''Return factory producing bucket objects for given storage-url
     
     If *plain* is true, don't attempt to unlock and don't wrap into
@@ -1194,10 +1158,9 @@ def get_bucket_factory(options, plain=False):
         else:
             backend_pw = sys.stdin.readline().rstrip()
 
-
-
     try:
-        bucket = bucket_class(options.storage_url, backend_login, backend_pw)
+        bucket = bucket_class(options.storage_url, backend_login, backend_pw,
+                              options.ssl)
         
         # Do not use bucket.lookup(), this would use a HEAD request and
         # not provide any useful error messages if something goes wrong
@@ -1220,7 +1183,8 @@ def get_bucket_factory(options, plain=False):
         encrypted = True
         
     if plain:
-        return lambda: bucket_class(options.storage_url, backend_login, backend_pw)
+        return lambda: bucket_class(options.storage_url, backend_login, backend_pw,
+                                    options.ssl)
             
     if encrypted and not bucket_passphrase:
         if sys.stdin.isatty():
@@ -1237,7 +1201,8 @@ def get_bucket_factory(options, plain=False):
 
     if not encrypted:
         return lambda: BetterBucket(None, compress,
-                                    bucket_class(options.storage_url, backend_login, backend_pw))
+                                    bucket_class(options.storage_url, backend_login, backend_pw,
+                                                 options.ssl))
 
     tmp_bucket = BetterBucket(bucket_passphrase, compress, bucket)
 
@@ -1247,4 +1212,5 @@ def get_bucket_factory(options, plain=False):
         raise QuietError('Wrong bucket passphrase')
 
     return lambda: BetterBucket(data_pw, compress,
-                                bucket_class(options.storage_url, backend_login, backend_pw))
+                                bucket_class(options.storage_url, backend_login, backend_pw,
+                                             options.ssl))
