@@ -31,11 +31,14 @@ class Bucket(AbstractBucket):
     object will be immediately retrievable. 
     """
 
-    def __init__(self, storage_url, login, password):
+    def __init__(self, storage_url, login, password, use_ssl=True):
+        # Unused argument
+        #pylint: disable=W0613
+        
         super(Bucket, self).__init__()
 
         (host, port, bucket_name, prefix) = self._parse_storage_url(storage_url)
-        
+            
         self.hostname = host
         self.port = port
         self.bucket_name = bucket_name
@@ -298,25 +301,6 @@ class Bucket(AbstractBucket):
 
         return ObjectW(key, self, headers)
 
-    def is_get_consistent(self):
-        '''If True, objects retrievals are guaranteed to be up-to-date
-        
-        If this method returns True, then creating, deleting, or overwriting an
-        object is guaranteed to be immediately reflected in subsequent object
-        retrieval attempts.
-        '''
-        
-        return True
-
-    def is_list_create_consistent(self):
-        '''If True, new objects are guaranteed to show up in object listings
-        
-        If this method returns True, creation of objects will immediately be
-        reflected when retrieving the list of available objects.
-        '''
-        
-        return True
-
     def clear(self):
         """Delete all objects in bucket"""
         
