@@ -8,16 +8,13 @@ This program can be distributed under the terms of the GNU GPLv3.
 
 from __future__ import division, print_function, absolute_import
 from . import CURRENT_FS_REV
-from .backends.common import NoSuchObject, get_bucket
-from .common import (ROOT_INODE, inode_for_path, sha256_fh, get_path, BUFSIZE,
-    get_bucket_cachedir, setup_logging, QuietError, get_seq_no, CTRL_INODE,
-    stream_write_bz2, stream_read_bz2)
+from .backends.common import NoSuchObject, get_bucket, NoSuchBucket
+from .common import (ROOT_INODE, inode_for_path, sha256_fh, get_path, BUFSIZE, get_bucket_cachedir, 
+    setup_logging, QuietError, get_seq_no, stream_write_bz2, stream_read_bz2, CTRL_INODE)
 from .database import NoSuchRowError, Connection
-from .metadata import (restore_metadata, cycle_metadata, dump_metadata,
-    create_tables)
+from .metadata import restore_metadata, cycle_metadata, dump_metadata, create_tables
 from .parse_args import ArgumentParser
 from os.path import basename
-from s3ql.backends.common import NoSuchBucket
 import apsw
 import cPickle as pickle
 import logging
@@ -847,8 +844,7 @@ class Fsck(object):
             self.conn.execute('CREATE TEMPORARY TABLE missing AS '
                               'SELECT id FROM objects EXCEPT SELECT id FROM obj_ids')
             for (obj_id,) in self.conn.query('SELECT * FROM missing'):
-                if (not self.bucket.is_list_create_consistent()
-                    and ('s3ql_data_%d' % obj_id) in self.bucket):
+                if ('s3ql_data_%d' % obj_id) in self.bucket:
                     # Object was just not in list yet
                     continue
 
@@ -1034,6 +1030,7 @@ def parse_args(args):
     parser.add_authfile()
     parser.add_debug_modules()
     parser.add_quiet()
+    parser.add_ssl()
     parser.add_version()
     parser.add_storage_url()
 
@@ -1100,20 +1097,13 @@ def main(args=None):
                          'S3QL installation.')
 
     if param['seq_no'] < seq_no:
-        if bucket.is_get_consistent():
-            print(textwrap.fill(textwrap.dedent('''\
-                  Up to date metadata is not available. Probably the file system has not
-                  been properly unmounted and you should try to run fsck on the computer 
-                  where the file system has been mounted most recently.
-                  ''')))
-        else:
-            print(textwrap.fill(textwrap.dedent('''\
-                  Up to date metadata is not available. Either the file system has not
-                  been unmounted cleanly or the data has not yet propagated through the backend.
-                  In the later case, waiting for a while should fix the problem, in
-                  the former case you should try to run fsck on the computer where
-                  the file system has been mounted most recently
-                  ''')))
+        print(textwrap.fill(textwrap.dedent('''\
+              Backend reports that file system is still mounted elsewhere. Either the file system
+              has not been unmounted cleanly or the data has not yet propagated through the backend.
+              In the later case, waiting for a while should fix the problem, in the former case you
+              should try to run fsck on the computer where the file system has been mounted most
+              recently. 
+              ''')))
 
         print('Enter "continue" to use the outdated data anyway:',
               '> ', sep='\n', end='')
