@@ -8,16 +8,15 @@ This program can be distributed under the terms of the GNU GPLv3.
 
 from __future__ import division, print_function, absolute_import
 from . import fs, CURRENT_FS_REV
-from .backends.common import get_bucket_factory, BucketPool
+from .backends.common import get_bucket_factory, BucketPool, NoSuchBucket
 from .block_cache import BlockCache
-from .common import (setup_logging, get_bucket_cachedir, get_seq_no, QuietError,
-    stream_write_bz2, stream_read_bz2)
+from .common import (setup_logging, get_bucket_cachedir, get_seq_no, QuietError, stream_write_bz2, 
+    stream_read_bz2)
 from .daemonize import daemonize
 from .database import Connection
 from .inode_cache import InodeCache
 from .metadata import cycle_metadata, dump_metadata, restore_metadata
 from .parse_args import ArgumentParser
-from s3ql.backends.common import NoSuchBucket
 from threading import Thread
 import cPickle as pickle
 import llfuse
@@ -27,10 +26,10 @@ import signal
 import stat
 import sys
 import tempfile
-import textwrap
 import thread
 import threading
 import time
+    
 
 log = logging.getLogger("mount")
 
@@ -150,10 +149,10 @@ def main(args=None):
         log.info("FUSE main loop terminated.")
 
     except:
-        # Tell finally handle not to raise any exceptions
+        # Tell finally block not to raise any additional exceptions
         exc_info[:] = sys.exc_info()
 
-        log.exception('Encountered exception, trying to clean up...')
+        log.warn('Encountered exception, trying to clean up...')
 
         # We do *not* free the mountpoint on exception. Why? E.g. if someone is
         # mirroring the mountpoint, and it suddenly becomes empty, all the
@@ -166,7 +165,7 @@ def main(args=None):
         except:
             log.exception("Exception during cleanup:")
 
-        raise QuietError('Aborted with exception.')
+        raise
 
     else:
         # llfuse.close() still needs block_cache.
@@ -311,20 +310,7 @@ def get_metadata(bucket, cachepath):
 
     # Check for unclean shutdown
     if param['seq_no'] < seq_no:
-        if bucket.is_get_consistent():
-            raise QuietError(textwrap.fill(textwrap.dedent('''\
-                It appears that the file system is still mounted somewhere else. If this is not
-                the case, the file system may have not been unmounted cleanly and you should try
-                to run fsck on the computer where the file system has been mounted most recently.
-                ''')))
-        else:
-            raise QuietError(textwrap.fill(textwrap.dedent('''\
-                It appears that the file system is still mounted somewhere else. If this is not the
-                case, the file system may have not been unmounted cleanly or the data from the 
-                most-recent mount may have not yet propagated through the backend. In the later case,
-                waiting for a while should fix the problem, in the former case you should try to run
-                fsck on the computer where the file system has been mounted most recently.
-                ''')))
+        raise QuietError('Backend reports that fs is still mounted elsewhere, aborting.')       
 
     # Check revision
     if param['revision'] < CURRENT_FS_REV:
@@ -424,6 +410,7 @@ def parse_args(args):
     parser.add_authfile()
     parser.add_debug_modules()
     parser.add_quiet()
+    parser.add_ssl()
     parser.add_version()
     parser.add_storage_url()
 
@@ -475,8 +462,8 @@ def parse_args(args):
                       default=None, metavar='<no>',
                       help='Number of parallel upload threads to use (default: auto).')
     parser.add_argument("--nfs", action="store_true", default=False,
-                      help='Support export of S3QL file systems over NFS '
-                           '(default: %(default)s)')
+                      help='Enable some optimizations for exporting the file system '
+                           'over NFS. (default: %(default)s)')
 
     options = parser.parse_args(args)
 
