@@ -316,12 +316,6 @@ class TestBucketPool(AbstractBucket):
     def is_temp_failure(self, exc):
         return self.bucket.is_temp_failure(exc)
 
-    def is_get_consistent(self):
-        return self.bucket.is_get_consistent()
-
-    def is_list_create_consistent(self):
-        return self.bucket.is_get_consistent()
-
     def clear(self):
         return self.bucket.clear()
 
